:mod:`art.attacks.poisoning`
============================
.. automodule:: art.attacks.poisoning

Backdoor Attack DGM ReD
-----------------------
.. autoclass:: BackdoorAttackDGMReDTensorFlowV2
   :members:
   :special-members:

Backdoor Attack DGM Trail
-------------------------
.. autoclass:: BackdoorAttackDGMTrailTensorFlowV2
   :members:
   :special-members:

Adversarial Embedding Attack
----------------------------
.. autoclass:: PoisoningAttackAdversarialEmbedding
   :members:
   :special-members:

Backdoor Poisoning Attack
-------------------------
.. autoclass:: PoisoningAttackBackdoor
   :members:
   :special-members:

Hidden Trigger Backdoor Attack
------------------------------
.. autoclass:: HiddenTriggerBackdoor
   :members:
   :special-members:

Bullseye Polytope Attack
------------------------
.. autoclass:: BullseyePolytopeAttackPyTorch
   :members:
   :special-members:

Clean Label Backdoor Attack
---------------------------
.. autoclass:: PoisoningAttackCleanLabelBackdoor
   :members:
   :special-members:

Feature Collision Attack
------------------------
.. autoclass:: FeatureCollisionAttack
   :members:
   :special-members:

Gradient Matching Attack
------------------------
.. autoclass:: GradientMatchingAttack
   :members:
   :special-members:

Poisoning SVM Attack
--------------------
.. autoclass:: PoisoningAttackSVM
   :members:
   :special-members:

Sleeper Agent Attack
--------------------
.. autoclass:: SleeperAgentAttack
   :members:
   :special-members:
